Provides all the common types to use with Fetcher
Re-exports
pub use crate::package::Config;pub use crate::package::GHPackage;pub use crate::package::Mode;pub use crate::package::SimplePackage;pub use crate::val::GHValue;pub use crate::val::SimpleValue;pub use crate::Fetcher;
Traits
- Entry
- Entry trait that will be used to be able to fetch and cache data as the Key
- Entry
Key - Entry
Value